<%Page path="/bits/header" PAGENAME="support"%>

<H1>Support</H1>
<P>

Numquid, domine, cum tua sit aeternitas, ignoras, quae tibi dico, aut
ad tempus vides quod fit in tempore? cur ergo tibi tot rerum narrationes
digero? non utique per me noveris ea, sed affectum meum excito in te et
eorum, qui haec legunt, ut dicamus omnes: Magnus dominus et laudabilis
valde. iam dixi et dicam: amore amoris tui facio istuc. nam et oramus,
et tamen veritas ait: Novit pater vester quid vobis opus sit, priusquam
petatis ab eo. affectum ergo nostrum patefacimus in te, confitendo tibi
miserias nostras et misericordias tuas super nos, ut liberes nos omnino,
quoniam coepisti, ut desinamus esse miseri in nobis et beatificemur in te,
quoniam vocasti nos, ut simus pauperes spiritu et mites et lugentes, et
esurientes ac sitentes iustitiam, et misericordes et mundicordes et
pacifici. ecce narravi tibi multa, quae potui et quae volui, quoniam tu
prior voluisti, ut confiterer tibi, domino deo meo, quoniam bonus es,
quoniam in saeculum misericordia tua.

<%Page path="/bits/footer"%>
