<%Page path="/bits/header-admin"%>
<%SetArg name="CUSTOMER_ID" value={<%CgiParam/f name="customer_id" default=""%>}%>
<%SetArg name="PAYMETHOD_ID"  value={<%CgiParam/f name="id"          default="NONEXISTENT"%>}%>

<DIV ALIGN="center"><H1>Editing Pay Method</H1></DIV>

<DIV ALIGN="center">

<FORM METHOD="get"   ACTION="edit.html">
<INPUT TYPE="hidden" NAME="id"          VALUE="<%PAYMETHOD_ID%>">
<INPUT TYPE="hidden" NAME="customer_id" VALUE="<%CUSTOMER_ID%>">
<CENTER>
<%PayMethod
  mode="edit-object"
  uri="/Customers/<%CUSTOMER_ID%>/PayMethods"
  id="<%PAYMETHOD_ID%>"
  form.path="/bits/commerce/account/paymethod/edit-form"
  success.path="/bits/commerce/admin/account/paymethod/edit-success"
%>
</FORM>

<%Condition
  default.path="/bits/commerce/admin/account/footer-accounts"
  default.pass
%>

</DIV>

<%Page path="/bits/footer-admin"%>
