<%Page path="/bits/header" PAGENAME="account" VERIFY%>
<%SetArg name="ADDRESS_ID" value={<%CgiParam/f name="id" default="NONEXISTENT"%>}%>

<DIV ALIGN="center"><H1>Editing Shipping Address</H1></DIV>

<DIV ALIGN="center">

<FORM METHOD="get"   ACTION="edit.html">
<INPUT TYPE="hidden" NAME="id" VALUE="<%ADDRESS_ID%>">

<%Address
  mode="edit-object"
  base.clipboard={<%IdentifyUser/f
                    mode="check"
                    type="customer"
                    verified.path="/bits/commerce/account/customer-cb-uri"
                  %>/object}
  uri="Addresses"
  id="<%ADDRESS_ID%>"
  form.path="/bits/commerce/account/address/edit-form"
  success.path="/bits/commerce/account/address/edit-success"
%>
</FORM>

<%Condition
  default.path="/bits/commerce/account/footer-accounts"
  default.pass
%>

</DIV>

<%Page path="/bits/footer"%>
